@@ -3,7 +3,7 @@ package MOP4Import::Declare;
 use 5.010;
 use strict;
 use warnings qw(FATAL all NONFATAL misc);
-our $VERSION = '0.000_002';
+our $VERSION = '0.001';
 use Carp;
 use mro qw/c3/;
 
@@ -330,7 +330,7 @@ sub declare___field {
   push @$fields_array, $name;
 
   # Create accessor for all public fields.
-  if ($name =~ /^[a-z]/i) {
+  if ($name =~ /^[a-z]/i and not $obj->{no_getter}) {
     *{globref($opts->{objpkg}, $name)} = sub { $_[0]->{$name} };
   }
 
